@@ -41,6 +41,14 @@ Crypt::Spritz - Spritz stream cipher/hash/MAC/AEAD/CSPRNG family
  # $cleartext = $aead->decrypt ($ciphertext);
  $mac = $aead->mac;
 
+=head1 WARNING
+
+The best known result (early 2017) against Spritz is a distinguisher
+attack on 2**44 outputs with multiple keys/IVs, and on 2**60 outputs with
+a single key (see doi:10.1007/978-3-662-52993-5_4 for details). These are
+realistic attacks, so Spritz needs to be considered broken, although for
+low data applications it should still be useful.
+
 =head1 DESCRIPTION
 
 This module implements the Spritz spongelike function (with N=256), the
@@ -82,7 +90,7 @@ package Crypt::Spritz;
 
 use XSLoader;
 
-$VERSION = 1.01;
+$VERSION = 1.02;
 
 XSLoader::load __PACKAGE__, $VERSION;
 
