@@ -45,7 +45,8 @@
 /* spritz parameters/state type */
 
 enum {
-  spritz_N = 256
+  spritz_N              = 256,
+  spritz_aead_blocksize = spritz_N >> 2 /* 64 */
 };
 
 typedef struct
